diff -urN galeon.orig/src/galeon-window.c galeon-1.3.15/src/galeon-window.c
--- galeon.orig/src/galeon-window.c	2004-04-27 23:18:44.000000000 +0200
+++ galeon-1.3.15/src/galeon-window.c	2004-06-20 13:33:33.000000000 +0200
@@ -117,6 +117,9 @@
 #define ACCEPT_COOKIES_ALWAYS	0
 #define ACCEPT_COOKIES_CURRENT	1
 #define ACCEPT_COOKIES_NEVER	2
+#define VIEW_IMAGEANIM_CONT	0
+#define VIEW_IMAGEANIM_ONCE	1
+#define VIEW_IMAGEANIM_NEVER	2
 
 struct GaleonWindowPrivate
 {
@@ -299,6 +302,7 @@
 	{ "EditMenuAction", NULL, N_("_Edit"), NULL, NULL, NULL, },
 	{ "ViewMenuAction", NULL, N_("_View"), NULL, NULL, NULL, },
 	{ "ViewImagesMenuAction", NULL, N_("I_mages"), NULL, NULL, NULL },
+	{ "ViewImageAnimationMenuAction", NULL, N_("Image _Animation"), NULL, NULL, NULL },
 	{ "ViewEncodingMenuAction", NULL, N_("_Encoding"), NULL, NULL, NULL },
 	{ "ViewStylesMenuAction", NULL, N_("St_yles"), NULL, NULL, NULL  },
 	{ "WebMenuAction", NULL, N_("_Web"), NULL, NULL, NULL },
@@ -483,6 +487,17 @@
 
 static guint n_image_radio_entries = G_N_ELEMENTS (image_radio_entries);
 
+static GtkRadioActionEntry imageanim_radio_entries[] = {
+	{ "ViewImageAnimationContinuousAction", NULL, N_("_Continuous"), NULL,
+	  N_("Animate Continuously"), VIEW_IMAGEANIM_CONT },
+	{ "ViewImageAnimationOnceAction", NULL, N_("_Once"), NULL,
+	  N_("Animate Once"), VIEW_IMAGEANIM_ONCE },
+	{ "ViewImageAnimationNeverAction", NULL, N_("_Never"),  NULL,
+	  N_("Don't play animated images"), VIEW_IMAGEANIM_NEVER }
+};
+
+static guint n_imageanim_radio_entries = G_N_ELEMENTS (imageanim_radio_entries);
+
 /* Keep this in order, see radio_group_set_from_value */
 static GtkRadioActionEntry cookie_radio_entries[] = {
 	{ "WebCookiesAlwaysAction", NULL, N_("A_lways Allow"), NULL,
@@ -1178,6 +1193,15 @@
 }
 
 static void
+view_imageanim_policy_changed (GtkRadioAction *action, GtkRadioAction *current, 
+			    GaleonWindow *window)
+{
+	/* The current value is the gconf value */
+	gint val = gtk_radio_action_get_current_value (action);
+	eel_gconf_set_integer (CONF_FILTERING_ANIMATE_TYPE, val);
+}
+
+static void
 view_images_gconf_changed_cb(GConfClient *client,
 		             guint cnxn_id,
 			     GConfEntry *entry,
@@ -1188,6 +1212,16 @@
 }
 
 static void
+view_imageanim_gconf_changed_cb(GConfClient *client,
+		             guint cnxn_id,
+			     GConfEntry *entry,
+			     GaleonWindow *window)
+{
+	radio_group_set_from_value (window, imageanim_radio_entries,
+				    n_imageanim_radio_entries, entry->value);
+}
+
+static void
 setup_images_menu(GaleonWindow *window)
 {
 	GConfValue *gcvalue;
@@ -1202,6 +1236,20 @@
 }
 
 static void
+setup_imageanim_menu(GaleonWindow *window)
+{
+	GConfValue *gcvalue;
+	gcvalue = eel_gconf_get_value(CONF_FILTERING_ANIMATE_TYPE);
+	radio_group_set_from_value (window, imageanim_radio_entries,
+				    n_imageanim_radio_entries, gcvalue);
+	gconf_value_free (gcvalue);
+
+	galeon_notification_add(CONF_FILTERING_ANIMATE_TYPE, 
+				(GConfClientNotifyFunc)view_imageanim_gconf_changed_cb, 
+				window, &window->priv->notifiers);
+}
+
+static void
 sidebar_close_requested_cb (GaleonSidebar *sidebar, 
 			    GaleonWindow *window)
 {
@@ -1525,6 +1573,11 @@
 					    G_CALLBACK (view_images_policy_changed),
 					    window);
 
+	gtk_action_group_add_radio_actions (p->action_group, imageanim_radio_entries,
+					    n_imageanim_radio_entries, 0,
+					    G_CALLBACK (view_imageanim_policy_changed),
+					    window);
+
 	gtk_action_group_add_radio_actions (p->action_group, cookie_radio_entries,
 					    n_cookie_radio_entries, 0,
 					    G_CALLBACK (web_cookies_policy_changed),
@@ -1754,6 +1807,7 @@
 	/* Setup gtk menus */
 	setup_images_menu(window);
 	setup_web_menu(window);
+	setup_imageanim_menu(window);
 
 	p->css_menu = galeon_css_menu_new (window);
 	p->encoding_menu = galeon_encoding_menu_new (window);
diff -urN galeon.orig/ui/galeon-egg-ui.xml galeon-1.3.15/ui/galeon-egg-ui.xml
--- galeon.orig/ui/galeon-egg-ui.xml	2004-04-27 13:28:36.000000000 +0200
+++ galeon-1.3.15/ui/galeon-egg-ui.xml	2004-06-20 13:33:28.000000000 +0200
@@ -47,6 +47,11 @@
 		<menuitem name="ViewImagesCurrent" action="ViewImagesCurrentAction" />
 		<menuitem name="ViewImagesNever" action="ViewImagesNeverAction" />
 	</menu>
+	<menu name="Image Animation" action="ViewImageAnimationMenuAction">
+		<menuitem name="ViewImageAnimationContinuous" action="ViewImageAnimationContinuousAction" />
+		<menuitem name="ViewImageAnimationOnce" action="ViewImageAnimationOnceAction" />
+		<menuitem name="ViewImageAnimationNever" action="ViewImageAnimationNeverAction" />
+	</menu>
 	<menu name="Encoding" action="ViewEncodingMenuAction">
           <placeholder name="ViewEncodingPlaceholder"/>
         </menu>
